//
// Crater.h
// A crater on the moon.
//
//    Copyright 2002 by Akkana Peck.
// You may use or distribute this code under the terms of the GPL.
//

#ifndef CRATER_H
#define CRATER_H

class QPainter;

class Crater
{
public:
    Crater();
    Crater(char* name, char* description, int size,
           int longitude, int latitude);
    virtual ~Crater();

    void Init(char* name, char* description, int size,
              int longitude, int latitude);

    char* GetName()     { return mName; }
    char* GetDesc()     { return mDesc; }
    int GetSize()       { return mSize; }
    int GetLongitude()  { return mLongitude; }
    int GetLatitude()   { return mLatitude; }
    int GetX()          { return mX; }
    int GetY()          { return mY; }
    int GetSizeX()      { return mSizeX; }
    int GetSizeY()      { return mSizeY; }

    // Find the distance from a point to the crater's center.
    // If the point is inside the crater, we also set isInside.
    double Distance(double longitude, double latitude, int* isInside);

    // Paint() crashes.  I don't know why.  Don't use it.
    virtual void Paint(QPainter* p, int xcenter, int ycenter, int moonRadius);

    // Routines for looping over all known craters:
    static void ReadCraterFile(char* craterFileName, int moonRadius=1);
    static void InitLoop();
    static Crater* NextCrater();

protected:
    // We own all the strings used here, and must free them at exit.
    char* mName;
    char* mDesc;
    int mSize;
    int mLongitude;
    int mLatitude;

    // Coordinates on the current screen.
    // It would be nice for Crater not to have to know this,
    // but it's much faster to do the math only once at init time
    // and not have to keep recalculating.
    int mX, mY;
    int mSizeX, mSizeY;

    static int sMoonRadius;
    static int sCurIndex;
    static Crater* sCraterList;
    static int sNumCraters;
};

#endif // CRATER_H
